function [S,I,R] = SIRModel_244(r, c, ICs, Tf)
% This code runs an SIR model for disease spread. The system of differential equations used here is
%   S' = -r*S*I
%   I' = r*S*I - cI
%   R' = c*I
%
% The solution is computed using the RungeKutta method, with the helper
% method rungeKuttaSystemMethod. The system is solved from t=0 to t=Tf,
% with initial conditions ICs given as a 3 component vector.

DE = @(t, x) [-r.*x(1).*x(2); r.*x(1).*x(2) - c.*x(2); c*x(2)];

[~, x] = rungeKuttaSystemMethod(DE, 0, Tf, 1, ICs);

S = x(1, :);
I = x(2, :);
R = x(3, :);
end