function quiver2D244(f,g, x_min, x_max, y_min, y_max, col)
% quiver2D244.m
% Author: Matt Charnley
%
% This function draws a quiver plot for the ODE dx/dt = f(x,y), dy/dt = g(x,y) for
% x_min <= x <= x_max and y_min <= y <= y_max. The functions f and g should be
% passed in as an anonymous functions, f = @(x,y) ... 
%
% The function draws this quiver plot in color col in the current figure
% and generates a normalized version (all vectors are the same length)
% as the next figure, so that it can be accessed outside of this function.
% For this second figure, the magnitude of the arrows does not mean
% anything, but it is easier to see the direction of them. 
%
% It will start with
% hold on; and end with hold off;, so the figure needs to be cleared in the
% main file if needed.

nVecs = 30;
dx = (x_max - x_min)/nVecs;
dy = (y_max - y_min)/nVecs;

f(x_min:dx:x_max, y_min:dy:y_max);

[x_vals, y_vals] = meshgrid(x_min:dx:x_max, y_min:dy:y_max);

vx = f(x_vals, y_vals);
vy = g(x_vals, y_vals);

xn = vx./(sqrt(vx.^2 + vy.^2))*dx;
yn = vy./(sqrt(vx.^2 + vy.^2))*dy;

% figure(fNum)
hold on;

quiver(x_vals, y_vals, vx, vy, col);
axis([x_min, x_max, y_min, y_max]);
axis square;
hold off;

figure();
hold on;
quiver(x_vals,y_vals,xn,yn,0.8, col);
axis([x_min, x_max, y_min, y_max]);
axis square;
hold off;
